@@ -2,6 +2,7 @@ from datetime import datetime, timedelta
 
 from . import errors
 import pytest
+import time
 
 
 class TestGeneral:
@@ -535,20 +536,12 @@ class TestLoadData:
         assert bad_object_id in [obj["object_id"] for obj in objects]
 
     @pytest.mark.destination
-    @pytest.mark.load_data
+    @pytest.mark.load_test_slow
     def test_load_large_data(self,
-                             connector,
-                             good_object_id,
-                             mapping_object,
-                             _replace,
-                             five_column_dataset):
-        # FIXME: a potential issue here is that i do not have object name validation for "_bad" on an object_id
-        connector.load_data(five_column_dataset,
-                            good_object_id,
-                            mapping_object,
-                            _replace,
-                            batch_number=1,
-                            total_batches=1)
-        connector.authenticate()
-        objects = connector.get_objects()
-        assert bad_object_id in [obj["object_id"] for obj in objects]
+                             load_data):
+        start = time.time()
+        assert load_data
+        end = time.time()
+        elapsed_time = end - start
+        print(elapsed_time)
+        assert elapsed_time < 10 * 60
